pub(crate) struct FontFeatureValueMap {
map: HashMap<HashKey, FontFeatureValue>,
}Expand description
Stores accumulated data of all active @font-feature-value rules.
Fields
map: HashMap<HashKey, FontFeatureValue>Implementations
Sourceimpl FontFeatureValueMap
impl FontFeatureValueMap
Sourcepub(crate) fn lookup(
&self,
family_name: Atom,
kind: AlternateKindRequiringResolution,
name: Atom,
) -> Option<FontFeatureValue>
pub(crate) fn lookup( &self, family_name: Atom, kind: AlternateKindRequiringResolution, name: Atom, ) -> Option<FontFeatureValue>
Looks up a single identifier in the map.
Sourcepub(crate) fn add_rule(&mut self, rule: &FontFeatureValuesRule)
pub(crate) fn add_rule(&mut self, rule: &FontFeatureValuesRule)
Adds the values from a new @font-feature-values rule to the map.
Conflicting entries are overwritten, so it is the callers responsibility to add the rules in ascending cascade order.