struct HashKey {
family_name: Atom,
kind: AlternateKindRequiringResolution,
name: Atom,
}Expand description
A key for looking up identifiers inside a FontFeatureValueMap.
Fields
family_name: AtomThe name of the font that the feature name is defined for
kind: AlternateKindRequiringResolutionname: AtomThe name of the feature.