pub struct ResolvedFontVariantAlternates {
pub historical_forms: bool,
pub stylistic: Option<SingleValue>,
pub styleset: Vec<u32>,
pub character_variant: Vec<PairValues>,
pub swash: Option<SingleValue>,
pub ornaments: Option<SingleValue>,
pub annotation: Option<SingleValue>,
}Expand description
Stores the value of the font-variant-alternates property, with identifiers
resolved to font-specific values.
Fields
historical_forms: boolstylistic: Option<SingleValue>styleset: Vec<u32>character_variant: Vec<PairValues>swash: Option<SingleValue>ornaments: Option<SingleValue>annotation: Option<SingleValue>Trait Implementations
Sourceimpl Clone for ResolvedFontVariantAlternates
impl Clone for ResolvedFontVariantAlternates
Sourcefn clone(&self) -> ResolvedFontVariantAlternates
fn clone(&self) -> ResolvedFontVariantAlternates
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ResolvedFontVariantAlternates
impl Default for ResolvedFontVariantAlternates
Sourcefn default() -> ResolvedFontVariantAlternates
fn default() -> ResolvedFontVariantAlternates
Returns the “default value” for a type. Read more
Sourceimpl Hash for ResolvedFontVariantAlternates
impl Hash for ResolvedFontVariantAlternates
Sourceimpl MallocSizeOf for ResolvedFontVariantAlternates
impl MallocSizeOf for ResolvedFontVariantAlternates
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl PartialEq for ResolvedFontVariantAlternates
impl PartialEq for ResolvedFontVariantAlternates
Sourcefn eq(&self, other: &ResolvedFontVariantAlternates) -> bool
fn eq(&self, other: &ResolvedFontVariantAlternates) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ResolvedFontVariantAlternates
impl StructuralPartialEq for ResolvedFontVariantAlternates